var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { Connector } from '@web3-react/types';
export class Url extends Connector {
    /**
     * @param url - An RPC url.
     * @param connectEagerly - A flag indicating whether connection should be initiated when the class is constructed.
     */
    constructor(actions, url, connectEagerly = true) {
        super(actions);
        this.url = url;
        if (connectEagerly) {
            void this.initialize();
        }
    }
    initialize() {
        return __awaiter(this, void 0, void 0, function* () {
            this.actions.startActivation();
            // create the provider if necessary
            if (!this.provider) {
                // instantiate new provider
                const [JsonRpcProvider, Eip1193Bridge] = yield Promise.all([
                    import('@ethersproject/providers').then(({ JsonRpcProvider }) => JsonRpcProvider),
                    import('@ethersproject/experimental').then(({ Eip1193Bridge }) => Eip1193Bridge),
                ]);
                const provider = new JsonRpcProvider(this.url);
                this.provider = new Eip1193Bridge(provider.getSigner(), provider);
            }
            return this.provider
                .request({ method: 'eth_chainId' })
                .then((chainId) => {
                this.actions.update({ chainId, accounts: [] });
            })
                .catch((error) => {
                this.actions.reportError(error);
            });
        });
    }
    /** {@inheritdoc Connector.activate} */
    activate() {
        return __awaiter(this, void 0, void 0, function* () {
            return this.initialize();
        });
    }
}
